<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Užverti (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Suskleisti</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Išskleisti</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Pašalinti įspėjimą</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln žodis</numerusform>
            <numerusform>%Ln žodžiai</numerusform>
            <numerusform>%Ln žodžių</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minutė</numerusform>
            <numerusform>%Ln minutės</numerusform>
            <numerusform>%Ln minučių</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% iš %Ln minutės</numerusform>
            <numerusform>%L1% iš %Ln minučių</numerusform>
            <numerusform>%L1% iš %Ln minučių</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% iš %Ln žodžio</numerusform>
            <numerusform>%L1% iš %Ln žodžių</numerusform>
            <numerusform>%L1% iš %Ln žodžių</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Kasdienė eiga</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Ilgiausias ruožas</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Dabartinis ruožas</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Nėra</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n diena</numerusform>
            <numerusform>%n dienos</numerusform>
            <numerusform>%n dienų</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% kasdienio tikslo</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Nustatyti kalbą</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Be pavadinimo %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Tik-skaitymui)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Atsiprašome</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Nepavyko įrašyti &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Įrašyti failą kaip</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Nepavyko pakeisti &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Pervadinti failą</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Nepavyko pervadinti &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Įkelti failą iš naujo?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Įkelti iš naujo failą &apos;%1&apos; iš disko?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Visi neįrašyti pakeitimai bus prarasti.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Įkelti iš naujo</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Be pavadinimo %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Įrašymas grynu tekstu pašalins visą formatavimą. Pašalinti formatavimą?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Failas pasikeitė</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Failas &apos;%1&apos; buvo pakeistas kita programa.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Ar norite įkelti failą iš naujo?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Įkelti iš naujo</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Nepaisyti</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Failas ištrintas</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Failas %1 buvo ištrintas kita programa.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Jūs norite failą įrašyti ar užverti?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nepavyko atverti archyvo.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Ieškoti:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Pakeisti tekstu:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Nepaisyti raidžių lygio</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Tik pilni žodžiai</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Reguliarieji reiškiniai</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Ieškoti aukštyn</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Ieškoti žemyn</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Rasti</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Pakeisti</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Pakeisti &amp;visus</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Rasti</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Pakeisti</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Pakeisti %n egzempliorių?</numerusform>
            <numerusform>Pakeisti %n egzempliorius?</numerusform>
            <numerusform>Pakeisti %n egzempliorių?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Atsiprašome</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Frazė nerasta.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>ODT formatas</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>DOCX formatas</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>RTF formatas</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Grynas tekstas</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Visi failai</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Visi palaikomi failai</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Tikrinti rašybą...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Jokių pasiūlymų nerasta)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Atverti paveikslą</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Paveikslai</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalbą:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos kalba&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nepavyko atverti archyvo.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Nuostatos</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Bendra</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Įrankių juosta</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Rašybos tikrinimas</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Pasirinkite žodyną</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Atleiskite</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nepavyko atverti archyvo.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Archyve nėra tinkamo naudoti žodyno.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Spartieji klavišai</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Vienas ar daugiau sparčiųjų klavišų konfliktuoja. Ar norite tęsti?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>&quot;%1&quot; žodynas jau yra. Ar norite jį pakeisti?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Kasdienis tikslas</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Jokio</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minučių:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Žodžių:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Redagavimas</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Visuomet vertikaliai centruoti</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Blokuoti įterpimo žymeklį</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Glotninti šriftus</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Spausdinimo mašinėlės garsai</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Išmaniosios kabutės:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dvigubos</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Viengubos</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scenos</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Dalytuvas:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Įrašymas</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Įsiminti žymeklio vietą</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Skaičiuoti žodžius</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Skaičiuoti puslapius</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Skaičiuoti pastraipas</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Skaičiuoti simbolius</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Simbolių:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Pastraipų:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Žodžių skaičiavimo algoritmas</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Atstatyti kasdienę eigą šiandienai iki nulio?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Įrašyti baitų tvarkos žymę gryno teksto failuose</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Numatytasis formatas:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Atstatyti šiandieną</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Žurnalas</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Įsiminti žurnalą</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Rodyti ruožus</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Minimali eiga ruožui:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Aptikti žodžio ribas</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Dalinti simbolių skaičių iš šešių</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Skaičiuoti kiekvieną raidę kaip žodį</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Puslapių skaičiavimo algoritmas</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stilius</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Tik piktogramos</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Tik tekstas</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Tekstas šalia piktogramų</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Tekstas po piktogramomis</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Teksto vieta:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Veiksmai</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Kelti aukštyn</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Nuleisti žemyn</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Pridėti skirtuką</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komanda</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Spartusis klavišas</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Veiksmas</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Tikrinti rašybą, renkant tekstą</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Nepaisyti žodžių, parašytų DIDŽIOSIOMIS RAIDĖMIS</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Nepaisyti žodžių su skaičiais</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Kalba</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Šalinti</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Asmeninis žodynas</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Šalinti esamą žodyną?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Naudotojo sąsaja</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Visada rodyti slankjuostę</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Visada rodyti viršutinę juostą</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Visada rodyti apatinę juostą</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Nepalaikomas RTF failas.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Netikėtai pasiekta failo pabaiga.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Kelti scenas aukštyn</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Perjungti scenų sąrašą</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Rodyti scenų sąrašą (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Slėpti scenų sąrašą (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtruoti</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Leisti scenas žemyn</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Keisti scenų sąrašo dydį</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Numatytoji</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Tvarkyti seansus</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;esijos</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nauja</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dubliuoti</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Perjungti į</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Naujas seansas</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Dubliuoti seansą</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Pervadinti seansą</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Ištrinti pasirinktą seansą?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Seanso pavadinimas:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Atleiskite</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Užklaustas seanso pavadinimas jau yra naudojamas.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nauja...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Tvarkyti...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Išvalyti</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Atstatyti numatytąsias reikšmes</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Spartusis klavišas:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Keičiamos kabutės...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Prašome palaukti</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Tikrinama rašyba</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Pridėti</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>Nepa&amp;isyti</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>I&amp;gnoruoti visus</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Pakeisti</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Pa&amp;keisti visus</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Nėra žodyne:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Pakeisti į:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Tikrinama rašyba...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atšaukti</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Prašome palaukti</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Tęsti tikrinimą failo pradžioje?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Rašybos tikrinimas užbaigtas.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Simboliai</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Neseniai naudoti simboliai</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Visi simboliai</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Išsamiau</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Įterpti</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blokai</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Scenarijai</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Be pavadinimo %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Nėra paveikslo</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Iškloti</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centruoti</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Ištempti</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Ištempti proporcingai</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Pritraukti</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Dengiamumas:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Vieta:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Plotis:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Apvalinti teksto fono kampus</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Plotas:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Sulieti teksto foną</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Teksto fonas numeta šešėlį</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Vertikalus poslinkis:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Paraštės</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Langas:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Puslapis:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Įtraukti pirmą eilutę</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Prieš:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Po:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Pašalinti</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Redaguoti temą</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Lango fonas</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipas:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Spalva:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Paveikslas:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>taškelių</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Kairėje</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Teksto fonas</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dešinėje</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekstas</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Šriftas:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Neteisingai parašytas:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Eilučių intervalai</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Viengubas</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 eilutės</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dvigubas</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporcionalus</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Aukštis:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Pastraipos tarpai</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Tabuliacijos plotis:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nauja tema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Temos</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Numatytoji</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Švelniai mėlyna</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Senoji mokykla</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Kosminės svajonės</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Rašomasis stalas</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nauja</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dubliuoti</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Tinkinta</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Keisti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importuoti</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportuoti</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Ištrinti temą &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Temos (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importuoti temą</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Eksportuoti temą</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Geliantis dangus</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Žavesys</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Šnipų žaidimai</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Ramumas</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Ištrinti laikmatį?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Žodžių:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Puslapių:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Pastraipų:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Simbolių:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Nustatyti delsimą</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Nustatyti laiką</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Delsimas:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Laikas:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Signalas</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipas:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Raštelis:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redaguoti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Nėra aktyvių laikmačių</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Laikmačiai</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Naujas</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Paskiausi</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Atšaukti laikmačių redagavimą?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Įkeliamos temos</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Įkeliami garsai</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Be pavadinimo</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Atverti failą</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Apie FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Paprasta viso ekrano žodžių doroklė</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Autorių Teisės &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Naudoja piktogramas iš &lt;a href=%1&gt;Oxygen&lt;/a&gt; piktogramų temos</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;LGPL 3&lt;/a&gt; licenciją</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Simbolių: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Puslapių: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Pastraipų: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Žodžių: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Atveriama %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Be pavadinimo %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Pateikti visus dokumentus</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Perjungti į kitą dokumentą</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Perjungti į ankstesnį dokumentą</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Perjungti į pirmą dokumentą</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Perjungti į paskutinį dokumentą</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Perjungti į dokumentą %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Įkeliami nustatymai</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Avarinė talpykla nėra tinkama įrašymui.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Įspėjimas</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter nebaigė darbo sklandžiai.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Atkurti iš avarinės talpyklos?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Kai kurių failų nepavyko atverti.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Kai kurie failai buvo atverti tik skaitymui.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; yra naujesnis negu talpinama kopija.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Pakeisti naujesnį failą?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Įrašyti pakeitimus?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Prieš užveriant, įrašyti pakeitimus į failą &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Jeigu neįrašysite, jūsų pakeitimai bus prarasti.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Nepavyko įkelti spausdinimo mašinėlės garsus.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Failas</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Atverti</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Į&amp;kelti iš naujo</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Į&amp;rašyti</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Įrašyti kai&amp;p...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>Pe&amp;rvadinti...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Įrašyti &amp;visus</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Tvarkyti seansus</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Naujas seansas</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Spausdinti...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Išei&amp;ti</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Taisa</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Anuliuoti</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>A&amp;tkurti</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Iškirpti</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>K&amp;opijuoti</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Į&amp;dėti</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Įdėti &amp;neformatuotą</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Žymėti &amp;viską</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Žymėti &amp;sceną</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmatas</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Paryškintas</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Kursyvu</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>Pa&amp;brauktas</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Perbr&amp;auktas</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Viršutiniame indekse</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Apa&amp;tiniame indekse</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Lygiuoti kairė&amp;je</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Lygiuoti &amp;centre</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Lygiuoti &amp;dešinėje</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Lygiuoti &amp;iš abiejų pusių</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Mažinti įtrauką</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Didi&amp;nti įtrauką</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Blokas iš kairė&amp;s į dešinę</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Blokas iš d&amp;ešinės į kairę</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>Įr&amp;ankiai</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Rasti...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Rasti &amp;kitą</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Rasti a&amp;nkstesnį</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Pakeisti...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Išmaniosios ka&amp;butės</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Atnaujinti &amp;dokumentą</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Atnaujinti žymėji&amp;mą</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Raš&amp;ybos tikrinimas...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Nustatyti ka&amp;lbą...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Laikmačiai...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>&amp;Simboliai...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>Kas&amp;dienė eiga</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Rodyti įrankių &amp;juostą</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Rodyti meniu &amp;piktogramas</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Teksto &amp;dėmesio centras</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Visas ekranas</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>Suskle&amp;isti langą</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Temos...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Nuostatos...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Dėmesio centras išjungtas</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Dėmesio centras - viena eilutė</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Dėmesio centras - trys eilutės</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Pastraipa</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Dėmesio centras - pastraipa</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ž&amp;inynas</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programos ka&amp;lba...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Kai kurie failai buvo nepalaikomi, todėl negalėjo būti atverti.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>Išj&amp;ungtas</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Viena ei&amp;lutė</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Trys eilutės</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Pus&amp;lapio sąranka...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Antraštė</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Antraštė &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Antraštė &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Antraštė &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Antraštė &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Antraštė &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Antraštė &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normalus</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Atnaujinti dokumento išmaniąsias kabutes</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Atnaujinti žymėjimo išmaniąsias kabutes</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation>Failai, kuriuos atverti dabartiniame seanse.</translation>
    </message>
</context>
</TS>
